@@ -103,7 +103,7 @@ namespace gloox
   Client::Client( const std::string& server )
     : ClientBase( XMLNS_CLIENT, server ),
       m_rosterManager( 0 ), m_auth( 0 ),
-      m_presence( Presence::Available, JID() ), m_resourceBound( false ),
+      m_presence( Presence::Available, JID() ),
       m_forceNonSasl( false ), m_manageRoster( true ),
       m_smId( EmptyString ), m_smLocation( EmptyString ), m_smResume( false ), m_smWanted( false ), m_smMax( 0 ),
       m_streamFeatures( 0 )
@@ -115,7 +115,7 @@ namespace gloox
   Client::Client( const JID& jid, const std::string& password, int port )
     : ClientBase( XMLNS_CLIENT, password, EmptyString, port ),
       m_rosterManager( 0 ), m_auth( 0 ),
-      m_presence( Presence::Available, JID() ), m_resourceBound( false ),
+      m_presence( Presence::Available, JID() ),
       m_forceNonSasl( false ), m_manageRoster( true ),
       m_smId( EmptyString ), m_smLocation( EmptyString ), m_smResume( false ), m_smWanted( false ), m_smMax( 0 ),
       m_streamFeatures( 0 )
