@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2014 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2016 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -19,6 +19,10 @@
 #include "logsink.h"
 #include "mutex.h"
 
+#ifdef __MINGW32__
+#include <ws2tcpip.h>
+#endif
+
 #include <string>
 
 namespace gloox
@@ -34,7 +38,7 @@ namespace gloox
    *
    * You should not need to use this class directly.
    *
-   * @author Jakob Schroeter <js@camaya.net>
+   * @author Jakob Schröter <js@camaya.net>
    * @since 0.9
    */
   class GLOOX_API ConnectionTCPBase : public ConnectionBase
