@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2014 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -15,7 +15,7 @@
 #define DATAFORM_H__
 
 #include "dataformfieldcontainer.h"
-#include "stanzaextension.h"
+#include "adhocplugin.h"
 
 #include <string>
 #include <list>
@@ -50,10 +50,10 @@ namespace gloox
    *
    *
    *
-   * @author Jakob Schroeter <js@camaya.net>
+   * @author Jakob Schröter <js@camaya.net>
    * @since 0.7
    */
-  class GLOOX_API DataForm : public StanzaExtension, public DataFormFieldContainer
+  class GLOOX_API DataForm : public AdhocPlugin, public DataFormFieldContainer
   {
     public:
       /**
